@@ -1,23 +1,35 @@
+"""
+Main CLI entrypoint.
+"""
 import sys
 
 
 def print_info() -> None:
+    """
+    Print package info to stdout.
+    """
     print(
-        "Type annotations for boto3.Lambda 1.17.90\n"
-        "Version:         1.17.90.post1\n"
-        "Builder version: 4.16.1\n"
+        "Type annotations for boto3.Lambda 1.18.47\n"
+        "Version:         1.18.47\n"
+        "Builder version: 5.3.1\n"
         "Docs:            https://pypi.org/project/mypy-boto3-lambda/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/lambda.html#Lambda\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
 
 
 def print_version() -> None:
-    print("1.17.90.post1")
+    """
+    Print package version to stdout.
+    """
+    print("1.18.47")
 
 
 def main() -> None:
+    """
+    Main CLI entrypoint.
+    """
     if "--version" in sys.argv:
         return print_version()
     print_info()
