@@ -37,8 +37,9 @@ Usage::
     ```
 """
 import sys
-from typing import Iterator
+from typing import Generic, Iterator, TypeVar
 
+from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .literals import RuntimeType
@@ -76,9 +77,20 @@ __all__ = (
 )
 
 
+_ItemTypeDef = TypeVar("_ItemTypeDef")
+
+
+class _PageIterator(Generic[_ItemTypeDef], PageIterator):
+    def __iter__(self) -> Iterator[_ItemTypeDef]:
+        """
+        Proxy method to specify iterator item type.
+        """
+
+
 class ListAliasesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/lambda.html#Lambda.Paginator.ListAliases)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listaliasespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListAliases)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listaliasespaginator)
     """
 
     def paginate(
@@ -87,30 +99,32 @@ class ListAliasesPaginator(Boto3Paginator):
         FunctionName: str,
         FunctionVersion: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListAliasesResponseTypeDef]:
+    ) -> _PageIterator[ListAliasesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/lambda.html#Lambda.Paginator.ListAliases.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListAliases.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listaliasespaginator)
         """
 
 
 class ListCodeSigningConfigsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/lambda.html#Lambda.Paginator.ListCodeSigningConfigs)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listcodesigningconfigspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListCodeSigningConfigs)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listcodesigningconfigspaginator)
     """
 
     def paginate(
-        self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListCodeSigningConfigsResponseTypeDef]:
+        self, *, PaginationConfig: PaginatorConfigTypeDef = None
+    ) -> _PageIterator[ListCodeSigningConfigsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/lambda.html#Lambda.Paginator.ListCodeSigningConfigs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListCodeSigningConfigs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listcodesigningconfigspaginator)
         """
 
 
 class ListEventSourceMappingsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/lambda.html#Lambda.Paginator.ListEventSourceMappings)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listeventsourcemappingspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListEventSourceMappings)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listeventsourcemappingspaginator)
     """
 
     def paginate(
@@ -119,30 +133,32 @@ class ListEventSourceMappingsPaginator(Boto3Paginator):
         EventSourceArn: str = None,
         FunctionName: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListEventSourceMappingsResponseTypeDef]:
+    ) -> _PageIterator[ListEventSourceMappingsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/lambda.html#Lambda.Paginator.ListEventSourceMappings.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListEventSourceMappings.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listeventsourcemappingspaginator)
         """
 
 
 class ListFunctionEventInvokeConfigsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/lambda.html#Lambda.Paginator.ListFunctionEventInvokeConfigs)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listfunctioneventinvokeconfigspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListFunctionEventInvokeConfigs)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listfunctioneventinvokeconfigspaginator)
     """
 
     def paginate(
-        self, FunctionName: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListFunctionEventInvokeConfigsResponseTypeDef]:
+        self, *, FunctionName: str, PaginationConfig: PaginatorConfigTypeDef = None
+    ) -> _PageIterator[ListFunctionEventInvokeConfigsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/lambda.html#Lambda.Paginator.ListFunctionEventInvokeConfigs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListFunctionEventInvokeConfigs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listfunctioneventinvokeconfigspaginator)
         """
 
 
 class ListFunctionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/lambda.html#Lambda.Paginator.ListFunctions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listfunctionspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListFunctions)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listfunctionspaginator)
     """
 
     def paginate(
@@ -151,30 +167,32 @@ class ListFunctionsPaginator(Boto3Paginator):
         MasterRegion: str = None,
         FunctionVersion: Literal["ALL"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListFunctionsResponseTypeDef]:
+    ) -> _PageIterator[ListFunctionsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/lambda.html#Lambda.Paginator.ListFunctions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListFunctions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listfunctionspaginator)
         """
 
 
 class ListFunctionsByCodeSigningConfigPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/lambda.html#Lambda.Paginator.ListFunctionsByCodeSigningConfig)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listfunctionsbycodesigningconfigpaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListFunctionsByCodeSigningConfig)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listfunctionsbycodesigningconfigpaginator)
     """
 
     def paginate(
-        self, CodeSigningConfigArn: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListFunctionsByCodeSigningConfigResponseTypeDef]:
+        self, *, CodeSigningConfigArn: str, PaginationConfig: PaginatorConfigTypeDef = None
+    ) -> _PageIterator[ListFunctionsByCodeSigningConfigResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/lambda.html#Lambda.Paginator.ListFunctionsByCodeSigningConfig.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListFunctionsByCodeSigningConfig.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listfunctionsbycodesigningconfigpaginator)
         """
 
 
 class ListLayerVersionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/lambda.html#Lambda.Paginator.ListLayerVersions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listlayerversionspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListLayerVersions)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listlayerversionspaginator)
     """
 
     def paginate(
@@ -183,50 +201,56 @@ class ListLayerVersionsPaginator(Boto3Paginator):
         LayerName: str,
         CompatibleRuntime: RuntimeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListLayerVersionsResponseTypeDef]:
+    ) -> _PageIterator[ListLayerVersionsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/lambda.html#Lambda.Paginator.ListLayerVersions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListLayerVersions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listlayerversionspaginator)
         """
 
 
 class ListLayersPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/lambda.html#Lambda.Paginator.ListLayers)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listlayerspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListLayers)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listlayerspaginator)
     """
 
     def paginate(
-        self, CompatibleRuntime: RuntimeType = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListLayersResponseTypeDef]:
+        self,
+        *,
+        CompatibleRuntime: RuntimeType = None,
+        PaginationConfig: PaginatorConfigTypeDef = None
+    ) -> _PageIterator[ListLayersResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/lambda.html#Lambda.Paginator.ListLayers.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListLayers.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listlayerspaginator)
         """
 
 
 class ListProvisionedConcurrencyConfigsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/lambda.html#Lambda.Paginator.ListProvisionedConcurrencyConfigs)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listprovisionedconcurrencyconfigspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListProvisionedConcurrencyConfigs)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listprovisionedconcurrencyconfigspaginator)
     """
 
     def paginate(
-        self, FunctionName: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListProvisionedConcurrencyConfigsResponseTypeDef]:
+        self, *, FunctionName: str, PaginationConfig: PaginatorConfigTypeDef = None
+    ) -> _PageIterator[ListProvisionedConcurrencyConfigsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/lambda.html#Lambda.Paginator.ListProvisionedConcurrencyConfigs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListProvisionedConcurrencyConfigs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listprovisionedconcurrencyconfigspaginator)
         """
 
 
 class ListVersionsByFunctionPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/lambda.html#Lambda.Paginator.ListVersionsByFunction)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listversionsbyfunctionpaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListVersionsByFunction)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listversionsbyfunctionpaginator)
     """
 
     def paginate(
-        self, FunctionName: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListVersionsByFunctionResponseTypeDef]:
+        self, *, FunctionName: str, PaginationConfig: PaginatorConfigTypeDef = None
+    ) -> _PageIterator[ListVersionsByFunctionResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/lambda.html#Lambda.Paginator.ListVersionsByFunction.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/lambda.html#Lambda.Paginator.ListVersionsByFunction.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lambda/paginators.html#listversionsbyfunctionpaginator)
         """
